@@ -3,7 +3,7 @@
  * From Binary XML Content Format Specification Version 1.3, 25 July 2001
  * found at http://www.wapforum.org
  *
- * Copyright 2003-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.horde.org/licenses/lgpl21.
@@ -49,7 +49,7 @@ class Horde_Xml_Wbxml_Encoder extends Horde_Xml_Wbxml_ContentHandler
     /**
      * Constructor.
      */
-    public function Horde_Xml_Wbxml_Encoder()
+    public function __construct()
     {
         $this->_dtdManager = new Horde_Xml_Wbxml_DtdManager();
         $this->_stringTable = new Horde_Xml_Wbxml_HashTable();
@@ -213,7 +213,7 @@ class Horde_Xml_Wbxml_Encoder extends Horde_Xml_Wbxml_ContentHandler
 
         $bytes = array();
         for ($i = 0; $i < $nbytes; $i++) {
-            $bytes[] = $string{$i};
+            $bytes[] = $string[$i];
         }
 
         return $bytes;
@@ -422,7 +422,7 @@ class Horde_Xml_Wbxml_Encoder extends Horde_Xml_Wbxml_ContentHandler
             $this->_output .= chr(Horde_Xml_Wbxml::GLOBAL_TOKEN_SWITCH_PAGE);
             $this->_output .= chr($cp);
         } else {
-            $this->_subParser = new Horde_Xml_Wbxml_Encoder(true);
+            $this->_subParser = new Horde_Xml_Wbxml_Encoder();
             $this->_subParserStack = 1;
         }
     }
